class Admin::PagePartsController < OrbitBackendController
  include Admin::FrontendWidgetInterface
  layout "structure"
  before_filter :authenticate_user!
  before_filter :is_admin?
  before_filter :set_current_item

  helper 'admin/items'
  
  def show
    @part = PagePart.find(params[:id])
    respond_to do |format|
      format.html { 
        render 'admin/items/index' 
      }
      format.js  {}
    end
  end


  def edit
    @part = PagePart.find(params[:id])
    @r_tag = @part.public_r_tag.blank? ? LIST[:public_r_tags][0] : @part.public_r_tag
    @tag_objects = @r_tag.classify.constantize.all rescue nil
    if @r_tag.eql?('tag_cloud')
      @tag_objects = ModuleApp.where(has_tag: true)
    else
      @tag_objects = @r_tag.classify.constantize.all rescue nil
    end

    @module_apps = ModuleApp.for_widget_select
    @categories = nil
    @tags = nil
    @page_frontend_data_counts = nil
    # @frontend_styles = nil

    @selected={
      :module_app=> @part.module_app ? @part.module_app : nil,
      :app_frontend_url=> @part.widget_path || "default_widget", #@module_apps.first
      :category=>nil, #fetch by method: get_categories_and_tags
      :tag=>nil, #fetch by method: get_categories_and_tags
      :page_frontend_data_count=>nil,
      :frontend_style => nil,
      :widget_path=> nil
    }

    @selected[:widget_path] = @part.widget_path ? @part.widget_path : (@selected[:module_app].widgets.keys[0] rescue nil)
    get_categories_and_tags
    get_frontend_data_count
    @app_frontend_urls = get_app_frontend_urls
    @no_orbit_bar = @side_bar = @no_header = true
  end

  def reload_widgets
    @part = PagePart.find params[:id]
    @selected={
      :module_app=> ModuleApp.find(params["module_app_id"])
    }
    get_categories_and_tags
    get_frontend_data_count
   @selected[:app_frontend_url] = @selected[:module_app].has_default_widget? ?  'default_widget' :  @selected[:module_app].widget_options.first.name
  end

  
  def reload_widget_styles
      @part = PagePart.find(params[:id])
      @selected={
      :module_app=> ModuleApp.find(params["module_app_id"]),
      :app_frontend_url=> params["frontend"], #@module_apps.first
      :category=>nil, #fetch by method: get_categories_and_tags
      :tag=>nil, #fetch by method: get_categories_and_tags
      :page_frontend_data_count=>nil,
      :frontend_style => nil,
      :widget_path=> nil
    }
    get_categories_and_tags
    get_frontend_data_count
  end

  def reload_widget_field
    @index = params[:field_seri].to_i
    @part = PagePart.find(params[:id])
    @selected = {
      :module_app=> ModuleApp.find(params["module_app_id"]),
      :default_widget_field=>params[:widget_field_value]
    }
  end

  def update

    @part = PagePart.find(params[:id])


    clean_tags_and_category_params

    # params[:page_part][:widget_field].each{|t| t[2] = (t[2]=="true" ? true : false )} if !params[:page_part][:widget_field].blank?
    if @part.update_attributes(params[:page_part])
      set_children_sub_menu(@part) if @part.public_r_tag && @part.public_r_tag.eql?('sub_menu')
      flash.now[:notice] = t('update.success.content')

      if @part.page.name == 'home'
        expire_page '/'
      else
        expire_page page_path(@part.page.name)
      end
      respond_to do |format|
        format.html { 
          redirect_to admin_page_url( @part.page )
        }
        format.js  {
          @item = @part.page
        }
      end
    else
      render :action => "edit"
    end
  end

  def destroy
    @item = Page.find(params[:id])
    @item.destroy
    redirect_to admin_items_url( :parent_id => @item.parent_id )
  end
  
  def reload_r_tag_options
    @part = PagePart.find params[:id]
    @r_tag = params[:type]
    if params[:type].eql?('tag_cloud')
      @tag_objects = ModuleApp.where(has_tag: true)
    else
      @tag_objects = @r_tag.classify.constantize.all rescue nil
    end
    respond_to do |format|
      format.js  {}
    end
  end

  protected
  def get_app_frontend_urls
    @selected[:module_app] ? @selected[:module_app].widgets.collect{|k,v| [I18n.t(v["i18n"]),k]}  : []
    #   has_old_value =  @selected[:module_app].app_pages[@selected[:app_frontend_url]]
    #   @frontend_styles = has_old_value ? has_old_value["style"] : (@selected[:module_app].app_pages.first[1]["style"] rescue nil)
  end

  def set_children_sub_menu(part)
    part.page.children.each do |child|
      child_part = child.page_parts.detect{ |x| x.name.eql?(part.name) } rescue nil
      child_part.update_attributes(:kind => part.kind, :public_r_tag => part.public_r_tag, :public_r_tag_object_id => part.public_r_tag_object_id) rescue nil
    end
  end
  
end
